#
# spec file for package prometheus-blackbox_exporter
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel} == 8
%global debug_package %{nil}
%endif

%if 0%{?rhel}
# Fix ERROR: No build ID note found in
%undefine _missing_build_ids_terminate_build
%endif

Name:           prometheus-blackbox_exporter
Version:        0.26.0
Release:        150000.1.27.1
Summary:        Prometheus blackbox prober exporter
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://prometheus.io/
Source0:        blackbox_exporter-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        prometheus-blackbox_exporter.service
# This patch has been applied before generating vendor tarball
Patch1:         0001-Bump-x-net.patch
BuildRequires:  fdupes
BuildRequires:  golang-github-prometheus-promu >= 0.17.0
%if 0%{?rhel}
BuildRequires:  golang >= 1.19
BuildRequires:  libcap
%else
BuildRequires:  libcap-progs
BuildRequires:  golang(API) >= 1.23
%endif
%{?systemd_ordering}
%if 0%{?suse_version}
Requires(pre):  user(prometheus)
Requires(pre):  group(prometheus)
Requires(post): permissions
%endif
ExcludeArch:    s390

%description
Prometheus blackbox exporter allows blackbox probing of endpoints over HTTP, HTTPS, DNS, TCP and ICMP.

%prep
%autosetup -a1 -p1 -n blackbox_exporter-%{version}

%build
%ifarch i586 s390x armv7hl armv7l armv7l:armv6l:armv5tel armv6hl
export BUILD_CGO_FLAG="--cgo"
%endif
export GOFLAGS="-buildmode=pie"
promu build -v $BUILD_CGO_FLAG

%install
install -D -m0755 %{_builddir}/blackbox_exporter-%{version}/blackbox_exporter-%{version} %{buildroot}%{_bindir}/blackbox_exporter
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/prometheus-blackbox_exporter.service
install -D -m0644 %{_builddir}/blackbox_exporter-%{version}/blackbox.yml %{buildroot}%{_sysconfdir}/prometheus/blackbox.yml
install -Dd -m0755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%fdupes %{buildroot}/%{_prefix}

%check
# Fix OBS debug_package execution.
rm -f %{buildroot}/usr/lib/debug/%{_bindir}/blackbox_exporter-%{version}-*.debug
go test -x .
%{buildroot}%{_bindir}/blackbox_exporter --version

%pre
%if 0%{?rhel}
%define serviceuser   prometheus
getent group %{serviceuser} >/dev/null || %{_sbindir}/groupadd -r %{serviceuser}
getent passwd %{serviceuser} >/dev/null || %{_sbindir}/useradd -r -g %{serviceuser} -d %{_localstatedir}/lib/%{serviceuser} -M -s /sbin/nologin %{serviceuser}
%else
%service_add_pre %{name}.service
%endif

%post
%if 0%{?rhel}
%systemd_post %{name}.service
%else
%service_add_post %{name}.service
%endif
# Because of more relaxed ping_group_range setting in sysctl in SLE/openSUSE 15
# everyone is allowed to create IPPROTO_ICMP sockets
# and hence no need to set capability
%if 0%{?suse_version} == 1315
  %set_permissions %{_bindir}/blackbox_exporter
%endif

%if 0%{?suse_version} == 1315
%verifyscript
  %verify_permissions -e %{_bindir}/blackbox_exporter
%endif

%preun
%if 0%{?rhel}
%systemd_preun %{name}.service
%else
%service_del_preun %{name}.service
%endif

%postun
%if 0%{?rhel}
%systemd_postun %{name}.service
%else
%service_del_postun %{name}.service
%endif

%files
%defattr(-,root,root)
%doc CHANGELOG.md README.md
%license LICENSE
%verify(not caps) %attr(755,root,root) %{_bindir}/blackbox_exporter
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%dir %{_sysconfdir}/prometheus
%config(noreplace) %{_sysconfdir}/prometheus/blackbox.yml

%changelog
* Tue May 27 2025 witold.bedyk@suse.com
- Rebase 0001-Bump-x-net.patch.
- Upgrade to version 0.26.0 (jsc#PED-12872):
  * Changes:
    Replace go-kit/log with log/slog module.
  * Features:
    Add metric to record tls ciphersuite negotiated during
    handshake.
    Add a way to export labels with content matched by the probe.
    Reports Certificate Serial number.
  * Enhancement:
    Add stale workflow to start sync with stale.yaml in Prometheus.
  * Bug fixes:
    Only register grpc TLS metrics on successful handshake.
- Upgrade to version 0.25.0:
  * Features:
    Allow to get Probe logs by target.
    Log errors from probe.
  * Bug fixes:
    Prevent logging confusing error message.
    Explicit registration of internal exporter metrics.
* Fri May 16 2025 witold.bedyk@suse.com
- Security:
  * CVE-2025-22870: Fix proxy bypassing using IPv6 zone IDs
    (bsc#1238680)
  * CVE-2023-45288: Fix closing connections when receiving too many
    headers (bsc#1236515)
- Add 0001-Bump-x-net.patch
- Use `manual` build service
- Build with `promu`
- Drop Go packaging macros
- Add testing
* Mon Jun 26 2023 witold.bedyk@suse.com
- Use obscpio for go modules service
- Set version number
- Set build date from SOURCE_DATE_EPOCH
* Fri Jun 16 2023 luizluca@tre-sc.jus.br
- Update to 0.24.0 (bsc#1212279, jsc#PED-4556)
  * Requires go1.19
- Drop:
  * 0001-Update-go-modules.patch
* Wed May 17 2023 witold.bedyk@suse.com
- Avoid empty validation script
- Add rc symlink for backwards compatibility
* Thu Apr 27 2023 witold.bedyk@suse.com
- Fix authentication bypass via cache poisoning
  (CVE-2022-46146, bsc#1208062)
- Add `min_version` parameter of `tls_config` to allow enabling
  TLS 1.0 and 1.1 (bsc#1209113)
- Add:
  * 0001-Update-go-modules.patch
* Mon Apr 24 2023 marina.latini@suse.com
- On SUSE Linux Enterprise build always with Go >= 1.19 (bsc#1203599)
* Fri Mar  3 2023 marina.latini@suse.com
- Build with go1.18 only for SLE-15-SP3 and
  build with >= go1.19 on higher SP (bsc#1203599)
* Tue Sep 27 2022 marina.latini@suse.com
- Require go1.18 (bsc#1203599, GH#19127)
* Thu Jun 16 2022 jgonzalez@suse.com
- Exclude s390 arch
* Tue May 10 2022 witold.bedyk@suse.com
- Fix %%pre section to avoid empty content
* Tue Feb 22 2022 stefan.bluhm@clacee.eu
- Updated to allow building on older rpmbuild.
* Sat Jan 22 2022 stefan.bluhm@clacee.eu
- Enhanced to build on Enterprise Linux 8
* Wed Sep 29 2021 witold.bedyk@suse.com
- Use %%set_permissions and %%verify_permissions for SLE 12 (bsc#1191194)
- Remove %%{go_nostrip}
* Tue Sep 21 2021 witold.bedyk@suse.com
- Remove BuildRoot:
* Tue Sep 14 2021 witold.bedyk@suse.com
- Clean up spec file formatting (jsc#SLE-22351)
* Tue Aug 24 2021 witold.bedyk@suse.com
- Set CAP_NET_RAW capability to allow ICMP requests
* Tue Aug 17 2021 witold.bedyk@suse.com
- Initial package, version 0.19.0
